
type 'a t
  (** ensemble d'éléments de type ['a], réalisé par une table de hachage *)

val create: int -> 'a t
  (** [create n] renvoie une table vide, de capacité [n] (c'est-à-dire avec
      [n] seaux) *)

val size: 'a t -> int
  (** renvoie le nombre d'éléments *)

(** Les fonctions [add] et [find] ci-dessous utilisent une fonction de hachage
    et une fonction d'égalité passées en argument.
    Ces fonctions doivent être cohérentes : deux valeurs égales pour [eq]
    doivent avoir la même valeur pour [hash]. *)

val add: ('a -> int) -> ('a -> 'a -> bool) -> 'a t -> 'a -> unit
  (** [add hash eq h x] ajoute l'élément [x] à la table [h], s'il n'est
      pas déjà présent ; sinon, la table reste inchangée *)

val find: ('a -> int) -> ('a -> 'a -> bool) -> 'a t -> 'a -> 'a option
  (** [find hash eq h x] renvoie [Some y] si un élément [y] dans la table [h]
      est égal à [x] (pour [eq]) et [None] sinon *)

val find_or_add: ('a -> int) -> ('a -> 'a -> bool) -> 'a t -> 'a -> 'a
  (** [find_or_add hash eq h x] ajoute l'élément [x] à la table [h] s'il n'est
      pas déjà présent et le renvoie ; sinon, renvoie l'élément égal déjà
      contenu dans la table *)


