
type 'a t
  (** ensemble d'éléments de type ['a], réalisé par une table de hachage *)

val create: ('a -> int) -> ('a -> 'a -> bool) -> int -> 'a t
  (** [create hash eq n] renvoie une table vide, de capacité [n]
      (c'est-à-dire avec [n] seaux) qui utilise la fonction de hachage
      [hash] et l'égalité [eq].
      Ces deux fonctions doivent être cohérentes : deux valeurs égales pour [eq]
      doivent avoir la même valeur pour [hash]. *)

val size: 'a t -> int
  (** renvoie le nombre d'éléments *)

val add: 'a t -> 'a -> unit
  (** [add hash eq h x] ajoute l'élément [x] à la table [h], s'il n'est
      pas déjà présent; sinon, la table reste inchangée *)

val find: 'a t -> 'a -> 'a option
  (** [find hash eq h x] renvoie [Some y] si un élément [y] dans la table [h]
      est égal à [x] (pour [eq]) et [None] sinon *)

